@@ -1,7 +1,5 @@
 """Authentication-related signals."""
 
-from __future__ import unicode_literals
-
 from django.dispatch import Signal
 
 
@@ -14,4 +12,4 @@ from django.dispatch import Signal
 #: Args:
 #:     user (django.contrib.auth.models.User):
 #:         The user that was newly registered.
-user_registered = Signal(providing_args=["user"])
+user_registered = Signal()
