@@ -1,7 +1,5 @@
 """A cache backend that forwards to other dynamically-configured backends."""
 
-from __future__ import unicode_literals
-
 import threading
 
 from django.core.signals import request_finished
@@ -52,7 +50,7 @@ class ForwardingCacheBackend(object):
         if self._backend:
             try:
                 self._backend.close()
-            except:
+            except Exception:
                 # We don't really care if this fails. We just want the new
                 # configuration.
                 pass
@@ -79,16 +77,9 @@ class ForwardingCacheBackend(object):
 
         with self._load_lock:
             if self._load_gen == cur_load_gen:
-                try:
-                    # Django >= 1.7
-                    from django.core.cache import caches
+                from django.core.cache import caches
 
-                    self._backend = caches[self._cache_name]
-                except ImportError:
-                    # Django < 1.7
-                    from django.core.cache import get_cache
-
-                    self._backend = get_cache(self._cache_name)
+                self._backend = caches[self._cache_name]
 
                 # get_cache will attempt to connect to 'close', which we don't
                 # want. Instead, go and disconnect this.
