@@ -1,12 +1,8 @@
 """Base support for configuration forms."""
 
-from __future__ import unicode_literals
-
 from django import forms
-from django.utils import six
-from django.utils.translation import ugettext_lazy as _
-
-from djblets.util.compat.django.template.loader import render_to_string
+from django.template.loader import render_to_string
+from django.utils.translation import gettext_lazy as _
 
 
 class ConfigPageForm(forms.Form):
@@ -88,7 +84,7 @@ class ConfigPageForm(forms.Form):
             field_values (dict):
                 The initial field data to set on the form.
         """
-        for field, value in six.iteritems(field_values):
+        for field, value in field_values.items():
             self.fields[field].initial = value
 
     def is_visible(self):
