@@ -1,28 +1,3 @@
-#
-# grids.py -- Basic definitions for datagrids
-#
-# Copyright (c) 2008-2009  Christian Hammond
-# Copyright (c) 2008-2009  David Trowbridge
-#
-# Permission is hereby granted, free of charge, to any person obtaining
-# a copy of this software and associated documentation files (the
-# "Software"), to deal in the Software without restriction, including
-# without limitation the rights to use, copy, modify, merge, publish,
-# distribute, sublicense, and/or sell copies of the Software, and to
-# permit persons to whom the Software is furnished to do so, subject to
-# the following conditions:
-#
-# The above copyright notice and this permission notice shall be included
-# in all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
 """Components for creating customizable datagrids from database data.
 
 Datagrids are used to display a table-based view of data from a database,
@@ -47,8 +22,6 @@ There are two main types of datagrids:
 All datagrids are meant to be subclassed.
 """
 
-from __future__ import unicode_literals
-
 import logging
 import re
 import string
@@ -57,27 +30,17 @@ import traceback
 import pytz
 from django.conf import settings
 from django.core.exceptions import ObjectDoesNotExist
-from django.core.paginator import InvalidPage, QuerySetPaginator
+from django.core.paginator import InvalidPage, Paginator
 from django.http import Http404, HttpResponse
 from django.template.defaultfilters import date, timesince
-from django.template.loader import get_template
-from django.utils import six
+from django.template.loader import get_template, render_to_string
 from django.utils.cache import patch_cache_control
 from django.utils.html import escape, format_html
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy as _
-
-try:
-    from django.contrib.auth.models import SiteProfileNotAvailable
-except ImportError:
-    # Django >= 1.7
-    class SiteProfileNotAvailable(Exception):
-        pass
+from django.utils.translation import gettext_lazy as _
 
+from djblets.deprecation import RemovedInDjblets40Warning
 from djblets.template.context import get_default_template_context_processors
-from djblets.db.query import chainable_select_related_queryset
-from djblets.util.compat.django.template.loader import (render_template,
-                                                        render_to_string)
 from djblets.util.decorators import cached_property
 from djblets.util.http import get_url_params_except
 
@@ -379,7 +342,7 @@ class Column(object):
             unsort_url = url_prefix + ','.join(sort_list[1:])
             sort_url = url_prefix + ','.join(sort_list)
 
-        return render_template(datagrid.column_header_template_obj, {
+        return datagrid.column_header_template_obj.render(context={
             'column': self,
             'column_state': state,
             'in_sort': in_sort,
@@ -471,13 +434,13 @@ class Column(object):
                 url = render_context.get('_datagrid_object_url')
 
         if self.css_class:
-            if six.callable(self.css_class):
+            if callable(self.css_class):
                 css_class = self.css_class(obj)
             else:
                 css_class = self.css_class
 
         if self.link_css_class:
-            if six.callable(self.link_css_class):
+            if callable(self.link_css_class):
                 link_css_class = self.link_css_class(obj)
             else:
                 link_css_class = self.link_css_class
@@ -508,7 +471,7 @@ class Column(object):
             if template is None:
                 template = state.datagrid.cell_template_obj
 
-            state.cell_render_cache[key] = render_template(template, ctx)
+            state.cell_render_cache[key] = template.render(ctx)
 
         return state.cell_render_cache[key]
 
@@ -545,7 +508,7 @@ class Column(object):
                 if field_name:
                     value = getattr(value, field_name)
 
-                    if six.callable(value):
+                    if callable(value):
                         value = value()
 
             return escape(value)
@@ -898,7 +861,7 @@ class DataGrid(object):
         """
         cls._populate_columns()
 
-        return six.itervalues(_column_registry[cls])
+        return _column_registry[cls].values()
 
     @classmethod
     def _populate_columns(cls):
@@ -1066,12 +1029,13 @@ class DataGrid(object):
         profile_sort_list = None
         profile_columns_list = None
         profile = None
-        profile_dirty = False
+        profile_dirty_fields = []
+        profile_dirty_fields_all = False
 
         # Get the saved settings for this grid in the profile. These will
         # work as defaults and allow us to determine if we need to save
         # the profile.
-        if self.request.user.is_authenticated():
+        if self.request.user.is_authenticated:
             profile = self.get_user_profile()
 
             if profile:
@@ -1167,8 +1131,19 @@ class DataGrid(object):
 
         # A subclass might have some work to do for loading and saving
         # as well.
-        if self.load_extra_state(profile):
-            profile_dirty = True
+        load_state_result = self.load_extra_state(profile)
+
+        if isinstance(load_state_result, list):
+            profile_dirty_fields += load_state_result
+        else:
+            RemovedInDjblets40Warning.warn(
+                '%s.load_extra_state() returned a %s, but must return a '
+                'list of field names to save (or an empty list). This will '
+                'be required in Djblets 4.0.'
+                % (type(self).__name__, type(load_state_result)))
+
+            if load_state_result is True:
+                profile_dirty_fields_all = True
 
         # Now that we have all that, figure out if we need to save new
         # settings back to the profile.
@@ -1176,14 +1151,17 @@ class DataGrid(object):
             if (self.profile_columns_field and
                 colnames != profile_columns_list):
                 setattr(profile, self.profile_columns_field, colnames)
-                profile_dirty = True
+                profile_dirty_fields.append(self.profile_columns_field)
 
             if self.profile_sort_field and sort_str != profile_sort_list:
                 setattr(profile, self.profile_sort_field, sort_str)
-                profile_dirty = True
+                profile_dirty_fields.append(self.profile_sort_field)
 
-            if profile_dirty:
+            if profile_dirty_fields_all:
+                # This can be removed in Djblets 4.
                 profile.save()
+            elif profile_dirty_fields:
+                profile.save(update_fields=profile_dirty_fields)
 
         self.state_loaded = True
 
@@ -1202,8 +1180,6 @@ class DataGrid(object):
                 return self.request.user.get_profile()
             except ObjectDoesNotExist:
                 pass
-            except SiteProfileNotAvailable:
-                pass
 
         return None
 
@@ -1213,16 +1189,26 @@ class DataGrid(object):
         This is used by subclasses that may have additional data to load
         and save.
 
+        Version Changed:
+            3.0:
+            This should now return a list of field names to save in
+            ``profile``. Any other result is deprecated and will no longer be
+            supported in Djblets 4.0.
+
         Args:
-            profile (Model):
+            profile (django.db.models.Model):
                 The profile model instance to load from, if any.
 
         Returns:
-            bool:
-                Subclasses must return ``True`` if any profile-stored
-                state has changed, or ``False`` otherwise.
+            bool or list of str:
+            A list of field names on ``profile`` that have been modified and
+            should be saved.
+
+            Djblets 3.0 and older support ``True`` to save the entire object,
+            or ``False`` if fields weren't modified. This support will be
+            removed in Djblets 4.0.
         """
-        return False
+        return []
 
     def precompute_objects(self, render_context=None):
         """Pre-compute all objects used to render the datagrid.
@@ -1396,8 +1382,6 @@ class DataGrid(object):
             django.db.models.query.QuerySet:
             The resulting augmented QuerySet.
         """
-        queryset = chainable_select_related_queryset(queryset)
-
         for column in self.columns:
             try:
                 queryset = column.augment_queryset(queryset)
@@ -1459,7 +1443,7 @@ class DataGrid(object):
             HttpResponse: The HTTP response to send to the client.
         """
         response = HttpResponse(
-            six.text_type(self.render_listview(render_context)))
+            str(self.render_listview(render_context)))
         patch_cache_control(response, no_cache=True, no_store=True, max_age=0,
                             must_revalidate=True)
         return response
@@ -1565,8 +1549,7 @@ class DataGrid(object):
         Returns:
             A populated paginator object.
         """
-        return QuerySetPaginator(queryset, self.paginate_by,
-                                 self.paginate_orphans)
+        return Paginator(queryset, self.paginate_by, self.paginate_orphans)
 
     def _build_render_context(self):
         """Build a dictionary containing RequestContext contents.
