@@ -4,22 +4,18 @@ This module contains widgets that correspond to fields provided in
 :py:mod:`djblets.forms.fields`.
 """
 
-from __future__ import unicode_literals
-
 import copy
 from contextlib import contextmanager
 
 from django.forms import widgets
 from django.forms.widgets import HiddenInput
-from django.utils import six
-from django.utils.html import format_html_join
-from django.utils.six.moves import filter, range
-from django.utils.translation import ugettext as _
+from django.template.loader import render_to_string
+from django.utils.translation import gettext as _
 
 from djblets.conditions import ConditionSet
 from djblets.conditions.errors import (ConditionChoiceNotFoundError,
                                        ConditionOperatorNotFoundError)
-from djblets.util.compat.django.template.loader import render_to_string
+from djblets.deprecation import RemovedInDjblets40Warning
 
 
 class ConditionsWidget(widgets.Widget):
@@ -107,9 +103,8 @@ class ConditionsWidget(widgets.Widget):
         page will need in order to render this widget and any widgets used
         in the condition value fields.
 
-        Returns:
-            django.forms.widgets.Media:
-            The media to include on the path.
+        Type:
+            django.forms.widgets.Media
         """
         media = (widgets.Media() +
                  self.choice_widget.media +
@@ -198,7 +193,7 @@ class ConditionsWidget(widgets.Widget):
             'conditions': conditions,
         }
 
-    def render(self, name, value, attrs=None):
+    def render(self, name, value, attrs=None, renderer=None):
         """Render the widget to HTML.
 
         This will serialize all the choices, operators, and existing
@@ -215,6 +210,9 @@ class ConditionsWidget(widgets.Widget):
             attrs (dict, optional):
                 Additional HTML element attributes for the fields.
 
+            renderer (django.forms.renderers.BaseRenderer, optional):
+                The form renderer.
+
         Returns:
             django.utils.safestring.SafeText:
             The rendered HTML for the widget.
@@ -515,7 +513,7 @@ class ConditionsWidget(widgets.Widget):
             djblets.conditions.values.BaseConditionValueField:
             The resulting value field.
         """
-        if six.callable(value_field):
+        if callable(value_field):
             value_field = value_field()
 
         return value_field
@@ -576,7 +574,7 @@ class CopyableTextInput(widgets.TextInput):
 
     template_name = 'djblets_forms/copyable_text_input.html'
 
-    def render(self, name, value, attrs=None):
+    def render(self, name, value, attrs=None, renderer=None):
         """Render the widget.
 
         Args:
@@ -589,11 +587,16 @@ class CopyableTextInput(widgets.TextInput):
             attrs (dict):
                 The attributes of the widget.
 
+            renderer (django.forms.renderers.BaseRenderer, optional):
+                The form renderer.
+
         Returns:
             django.utils.safestring.SafeText:
             The rendered widget.
         """
-        field = super(CopyableTextInput, self).render(name, value, attrs)
+        context = self.get_context(name, value, attrs)
+        field = self._render('django/forms/widgets/text.html', context,
+                             renderer)
 
         return render_to_string(
             self.template_name,
@@ -604,7 +607,7 @@ class CopyableTextInput(widgets.TextInput):
 
 
 class ListEditWidget(widgets.Widget):
-    """A widget for editing a list of separated values.
+    """A widget for editing a list of values.
 
     .. note: The ``djblets-forms`` CSS and JS bundles are required to use this
              widget.
@@ -612,62 +615,203 @@ class ListEditWidget(widgets.Widget):
 
     template_name = 'djblets_forms/list_edit_widget.html'
 
-    def __init__(self, attrs=None, sep=','):
+    def __init__(self, attrs=None, sep=',', value_widget=widgets.TextInput):
         """Initialize the widget.
 
+        Version Changed:
+            3.0:
+            Added the ``value_widget`` parameter and the ability for this
+            widget to handle any list of values instead of only strings.
+
         Args:
             attrs (dict, optional):
-                The attributes of the ``<input>`` elements.
+                A dictionary containing HTML attributes to be set
+                on the rendered widget.
 
-            sep (unicode, optional):
+            sep (str, optional):
                 The item separator.
+
+            value_widget (django.forms.widgets.Widget, optional):
+                The widget for the values in the list.
         """
         super(ListEditWidget, self).__init__(attrs)
 
+        if isinstance(value_widget, type):
+            self._value_widget = value_widget()
+        else:
+            self._value_widget = value_widget
+
         self._sep = sep
 
-    def render(self, name, value, attrs=None):
+    @property
+    def media(self):
+        """Media needed for the widget.
+
+        This is used by the form to return all CSS/JavaScript media that the
+        page will need in order to render this widget and any widgets used
+        in the condition value fields.
+
+        Version Added:
+            3.0
+
+        Type:
+            django.forms.widgets.Media
+        """
+        return widgets.Media() + self._value_widget.media
+
+    def render(self, name, value, attrs=None, renderer=None):
         """Render the widget.
 
+        Version Changed:
+            3.0:
+            The ``value`` parameter can be a string or a list of any
+            type of values.
+
         Args:
-            name (unicode):
+            name (str):
                 The field name.
 
-            value (unicode):
+            value (list or str):
                 The field value.
 
             attrs (dict, optional):
                 Additional attributes.
 
+            renderer (django.forms.renderers.BaseRenderer, optional):
+                The form renderer.
+
         Returns:
             django.utils.safestring.SafeText:
             The rendered widget.
         """
+        use_legacy_behavior = 'false'
+
+        # If value is not a list we assume that it is a string and convert it
+        # to a list. This behaviour will be deprecated in the future.
+        if not isinstance(value, list):
+            RemovedInDjblets40Warning.warn(
+                ('Passing a string to this widget is deprecated and will be '
+                 'removed in Djblets 4.0. Pass a list instead.'),
+            )
+            use_legacy_behavior = 'true'
+            value = value or ''
+            value = list(
+                filter(None, (item.strip() for item in value.split(self._sep)))
+            )
+
+        context = self.get_context(name, value, attrs)
+        context['use_legacy_behavior'] = use_legacy_behavior
+        return render_to_string(self.template_name,
+                                context)
+
+    def get_context(self, name, value, attrs):
+        """Return context for the widget.
+
+        This will serialize all the values in the list of values
+        using the value_widget.
+
+        Version Added:
+            3.0
+
+        Args:
+
+            name (str):
+                The base form field name of the widget.
+
+            value (dict):
+                The list of values.
+
+            attrs (dict):
+                Additional HTML element attributes for the fields.
+
+        Returns:
+            dict:
+            The context data for the widget.
+        """
+        value_widget = self._value_widget
         attrs = self.build_attrs(attrs)
         id_ = attrs.pop('id')
+        rendered_rows = []
 
         if 'class' in attrs:
             attrs['class'] += ' djblets-c-list-edit-widget__input'
         else:
             attrs['class'] = 'djblets-c-list-edit-widget__input'
 
-        value = value or ''
-        value_list = list(
-            filter(len, (item.strip() for item in value.split(self._sep)))
-        )
+        for i, val in enumerate(value):
+            rendered_rows.append(value_widget.render(
+                name='%s_value[%s]' % (name, i),
+                value=val,
+                attrs=attrs))
 
-        return render_to_string(
-            self.template_name,
-            {
-                'name': name,
-                'value': value,
-                'attrs': format_html_join('', ' {0}="{1}"',
-                                          sorted(six.iteritems(attrs))),
-                'id': id_,
-                'remove_text': _('Remove this item.'),
-                'sep': self._sep,
-                'value_list': value_list,
-            })
+        rendered_empty_row = value_widget.render(
+            name='%s_value[0]' % (name),
+            value=None,
+            attrs=attrs)
+
+        return {
+            'name': name,
+            'id': id_,
+            'remove_text': _('Remove this item.'),
+            'rendered_rows': rendered_rows,
+            'rendered_empty_row': rendered_empty_row,
+        }
+
+    def value_from_datadict(self, data, files, name):
+        """Return a value for the field from a submitted form.
+
+        This serializes the data POSTed for the form into a format that the
+        field can use and validate.
+
+        Version Added:
+            3.0
+
+        Args:
+            data (django.http.request.QueryDict):
+                The dictionary containing form data.
+
+            files (django.http.request.QueryDict):
+                The dictionary containing uploaded files.
+
+            name (str):
+                The field name for the value to load.
+
+        Returns:
+            list or str:
+            The list of values for the field or a string of separated
+            values for legacy behavior.
+        """
+        use_legacy_behavior = False
+        value_widget = self._value_widget
+        values = []
+
+        try:
+            num_rows = int(data['%s_num_rows' % name])
+            use_legacy_behavior = \
+                (data['%s_use_legacy_behavior' % name] == 'true')
+
+            for i in range(num_rows):
+                values.append(
+                    value_widget.value_from_datadict(
+                        data,
+                        files,
+                        '%s_value[%s]' % (name, i)))
+        except (KeyError, ValueError):
+            # In this case the widget was called but not rendered, so fetch
+            # the data from the field name key in the data dict instead of
+            # from the special keys that get set when the widget is rendered.
+            values = data[name]
+
+        # Return a string of separated values if using legacy behavior.
+        # This will be deprecated in the future.
+        if use_legacy_behavior:
+            RemovedInDjblets40Warning.warn(
+                ('Passing a string to this widget is deprecated and will be '
+                 'removed in Djblets 4.0. Pass a list instead.'),
+            )
+            return self._sep.join(values)
+
+        return values
 
     def id_for_label(self, id_):
         """Return the main ID to use for this widget.
@@ -676,11 +820,11 @@ class ListEditWidget(widgets.Widget):
         under this widget.
 
         Args:
-            id_ (unicode):
+            id_ (str):
                 The ID of the element.
 
         Returns:
-            unicode:
+            str:
             ``None`` so that no ``for=`` attribute is rendered on the label.
         """
         return None
