@@ -1,38 +1,9 @@
-#
-# __init__.py -- Gravatar functionality
-#
-# Copyright (c) 2012       Beanbag, Inc.
-# Copyright (c) 2008-2009  Christian Hammond
-#
-# Permission is hereby granted, free of charge, to any person obtaining
-# a copy of this software and associated documentation files (the
-# "Software"), to deal in the Software without restriction, including
-# without limitation the rights to use, copy, modify, merge, publish,
-# distribute, sublicense, and/or sell copies of the Software, and to
-# permit persons to whom the Software is furnished to do so, subject to
-# the following conditions:
-#
-# The above copyright notice and this permission notice shall be included
-# in all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-from __future__ import unicode_literals
+"""Utilities for working with gravatars."""
 
 from hashlib import md5
+from urllib.parse import urlencode
 
 from django.conf import settings
-from django.utils import six
-from django.utils.six.moves.urllib.parse import urlencode
-
-
-default_app_config = 'djblets.gravatars.apps.GravatarsAppConfig'
 
 
 def get_gravatar_url_for_email(email=None, size=None):
@@ -58,7 +29,7 @@ def get_gravatar_url_for_email(email=None, size=None):
     if email:
         email = email.strip().lower()
 
-        if isinstance(email, six.text_type):
+        if isinstance(email, str):
             email = email.encode('utf-8')
 
         email_hash = md5(email).hexdigest()
@@ -113,7 +84,7 @@ def get_gravatar_url(user=None, size=None):
     if user is None:
         raise ValueError('"user" cannot be None.')
 
-    if user.is_anonymous() or not user.email:
+    if user.is_anonymous or not user.email:
         return ''
 
     return get_gravatar_url_for_email(email=user.email, size=size)
