@@ -1,15 +1,12 @@
 """E-mail message composition and sending."""
 
-from __future__ import unicode_literals
-
 import logging
 from email.utils import parseaddr
 
 from django.conf import settings
 from django.core.mail import EmailMultiAlternatives
-from django.utils import six
 from django.utils.datastructures import MultiValueDict
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 
 from djblets.mail.dmarc import is_email_allowed_by_dmarc
 from djblets.mail.utils import build_email_address_via_service
@@ -166,7 +163,7 @@ class EmailMessage(EmailMultiAlternatives):
             # values are lists, so we have to ensure that ourselves.
             headers = MultiValueDict(dict(
                 (key, [value])
-                for key, value in six.iteritems(headers)
+                for key, value in headers.items()
             ))
 
         if in_reply_to:
@@ -262,7 +259,7 @@ class EmailMessage(EmailMultiAlternatives):
         # when communicating with the SMTP server.
         super(EmailMessage, self).__init__(
             subject=subject,
-            body=force_text(text_body),
+            body=force_str(text_body),
             from_email=settings.DEFAULT_FROM_EMAIL,
             to=to,
             cc=cc,
@@ -280,7 +277,7 @@ class EmailMessage(EmailMultiAlternatives):
         self._headers = headers
 
         if html_body:
-            self.attach_alternative(force_text(html_body), 'text/html')
+            self.attach_alternative(force_str(html_body), 'text/html')
 
     def message(self):
         """Construct an outgoing message for the e-mail.
@@ -302,7 +299,7 @@ class EmailMessage(EmailMultiAlternatives):
         msg = super(EmailMessage, self).message()
         self.message_id = msg['Message-ID']
 
-        for name, value_list in six.iterlists(self._headers):
+        for name, value_list in self._headers.lists():
             for value in value_list:
                 # Use the native string on each version of Python. These
                 # are headers, so they'll be convertible without encoding
