@@ -1,15 +1,10 @@
 """Extension hooks for consent requirements."""
 
-from __future__ import unicode_literals
-
-from django.utils import six
-
 from djblets.extensions.hooks import BaseRegistryHook, ExtensionHookPoint
 from djblets.privacy.consent.registry import get_consent_requirements_registry
 
 
-@six.add_metaclass(ExtensionHookPoint)
-class ConsentRequirementHook(BaseRegistryHook):
+class ConsentRequirementHook(BaseRegistryHook, metaclass=ExtensionHookPoint):
     """Registers a ConsentRequirement for use of personal data."""
 
     @property
