@@ -3,18 +3,16 @@
 See :ref:`using-recaptcha` for a guide on using reCAPTCHA validation.
 """
 
-from __future__ import unicode_literals
-
 import json
 import logging
+from urllib.error import HTTPError
+from urllib.parse import urlencode
+from urllib.request import urlopen
 
 from django import forms
 from django.conf import settings
 from django.core.exceptions import ValidationError
-from django.utils.six.moves.urllib.error import HTTPError
-from django.utils.six.moves.urllib.parse import urlencode
-from django.utils.six.moves.urllib.request import urlopen
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from djblets.recaptcha.widgets import RecaptchaWidget
 
