@@ -1,13 +1,10 @@
 """Unit tests for djblets.siteconfig."""
 
-from __future__ import unicode_literals
-
 import hmac
 
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.core.cache import cache
-from django.utils import six
 
 from djblets.siteconfig.django_settings import (apply_django_settings,
                                                 cache_settings_map,
@@ -49,8 +46,8 @@ class DjangoSettingsTests(SiteConfigTestCase):
         username = 'myuser'
         password = 'mypass'
 
-        self.assertEqual(type(username), six.text_type)
-        self.assertEqual(type(password), six.text_type)
+        self.assertEqual(type(username), str)
+        self.assertEqual(type(password), str)
 
         self.siteconfig.set('mail_host_user', username)
         self.siteconfig.set('mail_host_password', password)
@@ -93,8 +90,9 @@ class DjangoSettingsTests(SiteConfigTestCase):
         self.assertEqual(settings.CACHES['default']['LOCATION'],
                          'forwarded_backend')
 
-        self.assertEqual(settings.CACHES['forwarded_backend']['BACKEND'],
-                         'django.core.cache.backends.memcached.MemcachedCache')
+        self.assertEqual(
+            settings.CACHES['forwarded_backend']['BACKEND'],
+            'django.core.cache.backends.memcached.PyMemcacheCache')
         self.assertEqual(settings.CACHES['forwarded_backend']['LOCATION'],
                          'localhost:12345')
 
@@ -127,8 +125,9 @@ class DjangoSettingsTests(SiteConfigTestCase):
         self.assertEqual(settings.CACHES['default']['LOCATION'],
                          'forwarded_backend')
 
-        self.assertEqual(settings.CACHES['forwarded_backend']['BACKEND'],
-                         'django.core.cache.backends.memcached.MemcachedCache')
+        self.assertEqual(
+            settings.CACHES['forwarded_backend']['BACKEND'],
+            'django.core.cache.backends.memcached.PyMemcacheCache')
         self.assertEqual(settings.CACHES['forwarded_backend']['LOCATION'],
                          'localhost:12345')
 
@@ -161,8 +160,42 @@ class DjangoSettingsTests(SiteConfigTestCase):
         self.assertEqual(settings.CACHES['default']['LOCATION'],
                          'forwarded_backend')
 
-        self.assertEqual(settings.CACHES['forwarded_backend']['BACKEND'],
-                         'django.core.cache.backends.memcached.MemcachedCache')
+        self.assertEqual(
+            settings.CACHES['forwarded_backend']['BACKEND'],
+            'django.core.cache.backends.memcached.PyMemcacheCache')
+        self.assertEqual(settings.CACHES['forwarded_backend']['LOCATION'],
+                         'localhost:12345')
+
+    def test_cache_backend_pymemcache(self):
+        """Testing transition of old memcached backend to pymemcache"""
+        settings.CACHES['staticfiles'] = {
+            'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
+            'LOCATION': 'staticfiles-cache',
+        }
+
+        self.siteconfig.set('cache_backend', {
+            'default': {
+                'BACKEND':
+                    'django.core.cache.backends.memcached.MemcachedCache',
+                'LOCATION': 'localhost:12345',
+            },
+        })
+
+        apply_django_settings(self.siteconfig, cache_settings_map)
+
+        self.assertTrue('staticfiles' in settings.CACHES)
+        self.assertTrue('default' in settings.CACHES)
+        self.assertTrue('forwarded_backend' in settings.CACHES)
+
+        self.assertEqual(
+            settings.CACHES['default']['BACKEND'],
+            'djblets.cache.forwarding_backend.ForwardingCacheBackend')
+        self.assertEqual(settings.CACHES['default']['LOCATION'],
+                         'forwarded_backend')
+
+        self.assertEqual(
+            settings.CACHES['forwarded_backend']['BACKEND'],
+            'django.core.cache.backends.memcached.PyMemcacheCache')
         self.assertEqual(settings.CACHES['forwarded_backend']['LOCATION'],
                          'localhost:12345')
 
