@@ -7,12 +7,10 @@ Version Added:
     2.2.4
 """
 
-from __future__ import unicode_literals
-
 import sys
 
 
-if sys.version_info.major >= 3:
+if sys.version_info >= (3, 10):
     # Python 3.10+ removed a bunch of aliases from the collections module.
     # Unfortunately, Django 1.11 and nose still rely on these.
     try:
