@@ -1,29 +1,4 @@
-#
-# djblets_js.py -- JavaScript-related template tags
-#
-# Copyright (c) 2007-2009  Christian Hammond
-# Copyright (c) 2007-2009  David Trowbridge
-#
-# Permission is hereby granted, free of charge, to any person obtaining
-# a copy of this software and associated documentation files (the
-# "Software"), to deal in the Software without restriction, including
-# without limitation the rights to use, copy, modify, merge, publish,
-# distribute, sublicense, and/or sell copies of the Software, and to
-# permit persons to whom the Software is furnished to do so, subject to
-# the following conditions:
-#
-# The above copyright notice and this permission notice shall be included
-# in all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-from __future__ import unicode_literals
+"""JavaScript-related template tags."""
 
 import json
 
@@ -31,8 +6,7 @@ from django import template
 from django.core.serializers import serialize
 from django.db.models.query import QuerySet
 from django.template.defaultfilters import escapejs
-from django.utils import six
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.safestring import mark_safe
 
 from djblets.util.serializers import DjbletsJSONEncoder
@@ -70,7 +44,7 @@ def form_dialog_fields(form):
             if field.field.help_text:
                 s += "help_text: '%s', " % escapejs(field.field.help_text)
 
-        s += "widget: '%s' }," % escapejs(six.text_type(field))
+        s += "widget: '%s' }," % escapejs(str(field))
 
     # Chop off the last ','
     return "[ %s ]" % s[:-1]
@@ -86,7 +60,7 @@ def json_dumps(value, indent=None):
                             cls=DjbletsJSONEncoder,
                             sort_keys=True)
 
-    return mark_safe(force_text(result).translate(_safe_js_escapes))
+    return mark_safe(force_str(result).translate(_safe_js_escapes))
 
 
 @register.filter
