@@ -1,7 +1,5 @@
-from __future__ import unicode_literals
-
 from django.utils.translation import get_language
-from django.views.i18n import javascript_catalog
+from django.views.i18n import JavaScriptCatalog
 
 from djblets.cache.backend import cache_memoize
 from djblets.cache.serials import generate_locale_serial
@@ -23,6 +21,7 @@ def cached_javascript_catalog(request, domain='djangojs', packages=None):
 
     return cache_memoize(
         'jsi18n-%s-%s-%s-%d' % (domain, package_str, get_language(), serial),
-        lambda: javascript_catalog(request, domain, packages),
+        lambda: JavaScriptCatalog.as_view(domain=domain,
+                                          packages=packages)(request),
         large_data=True,
         compress_large_data=True)
