@@ -5,24 +5,32 @@ backend classes, and using them to perform an authentication based on an HTTP
 request.
 """
 
+from __future__ import annotations
+
 from importlib import import_module
+from typing import List, Optional, Type
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
+from django.http import HttpRequest
+
+from djblets.webapi.auth.backends.base import (WebAPIAuthBackend,
+                                               WebAPIAuthenticateResult)
 
 
-_auth_backends = []
+_auth_backends: List[Type[WebAPIAuthBackend]] = []
 
 
-def get_auth_backends():
+def get_auth_backends() -> List[Type[WebAPIAuthBackend]]:
     """Return the list of web API authentication backends.
 
-    This defaults to :py:class:`WebAPIBasicAuthBackend`, for HTTP Basic Auth,
-    but can be overridden by setting ``settings.WEB_API_AUTH_BACKENDS`` to a
-    list of class paths.
+    This defaults to :py:class:`~djblets.webapi.auth.backends.basic.
+    WebAPIBasicAuthBackend`, for HTTP Basic Auth, but can be overridden by
+    setting ``settings.WEB_API_AUTH_BACKENDS`` to a list of class paths.
 
     Returns:
-        list: A list of all usable authentication backend classes.
+        list:
+        A list of all usable authentication backend classes.
     """
     global _auth_backends
 
@@ -69,7 +77,9 @@ def reset_auth_backends():
     _auth_backends = []
 
 
-def check_login(request):
+def check_login(
+    request: HttpRequest,
+) -> Optional[WebAPIAuthenticateResult]:
     """Check if a login request was made.
 
     If the client specifies a ``HTTP_AUTHORIZATION`` header, this will attempt
@@ -79,7 +89,12 @@ def check_login(request):
         request (HttpRequest): The HTTP request from the client.
 
     Returns:
+        tuple:
         The result of the authentication, if successful, or ``None`` otherwise.
+
+        See :py:class:`~djblets.webapi.auth.backends.base.
+        WebAPIAuthenticateResult` for details on the format for the returned
+        type value.
     """
     if 'HTTP_AUTHORIZATION' in request.META:
         for auth_backend_cls in get_auth_backends():
