@@ -1,11 +1,21 @@
 """Web API support for OAuth2 authentication."""
 
+from __future__ import annotations
+
 import logging
 from importlib import import_module
+from typing import Optional, TYPE_CHECKING
 
+from django.contrib.auth.models import User
 from django.core.exceptions import ImproperlyConfigured
+from django.http import HttpRequest
 
-from djblets.webapi.auth.backends.base import WebAPIAuthBackend
+from djblets.webapi.auth.backends.base import (WebAPIAuthBackend,
+                                               WebAPIAuthenticateResult,
+                                               WebAPIGetCredentialsResult)
+
+if TYPE_CHECKING:
+    from oauth2_provider.models import AccessToken
 
 
 logger = logging.getLogger(__name__)
@@ -22,7 +32,11 @@ class OAuth2TokenBackendMixin(object):
                  implementation is based off of.
     """
 
-    def authenticate(self, request, **credentials):
+    def authenticate(
+        self,
+        request: HttpRequest,
+        **kwargs,
+    ) -> Optional[WebAPIAuthenticateResult]:
         """Attempt to authenticate a request.
 
         Args:
@@ -44,21 +58,26 @@ class OAuth2TokenBackendMixin(object):
             from oauth2_provider.oauth2_backends import get_oauthlib_core
         except ImportError:
             raise ImproperlyConfigured(
-                'WebAPIOAuth2TokenAuthBackend requires django-oauth-toolkit'
-                '>=0.9,<0.9.999.'
+                'WebAPIOAuth2TokenAuthBackend requires a compatible version '
+                'of django-oauth-toolkit.'
             )
 
         oauthlib_core = get_oauthlib_core()
         valid, r = oauthlib_core.verify_request(request, scopes=[])
 
         if valid and self.verify_request(request, r.access_token, r.user):
-            request._oauth2_token = r.access_token
+            setattr(request, '_oauth2_token', r.access_token)
             request.session['oauth2_token_id'] = r.access_token.pk
             return r.user
 
         return None
 
-    def verify_request(self, request, token, user):
+    def verify_request(
+        self,
+        request: HttpRequest,
+        token: AccessToken,
+        user: User,
+    ) -> bool:
         """Perform additional request verification.
 
         This method can be overrided by subclasses to perform additional
@@ -74,6 +93,13 @@ class OAuth2TokenBackendMixin(object):
 
             user (django.contrib.auth.models.User):
                 The user who is authenticating.
+
+        Returns:
+            bool:
+            ``True`` if the request can be verified. ``False`` if it cannot.
+
+            By default, this is always ``True``. Subclasses can override this
+            to perform additional checking.
         """
         return True
 
@@ -81,7 +107,10 @@ class OAuth2TokenBackendMixin(object):
 class WebAPIOAuth2TokenAuthBackend(WebAPIAuthBackend):
     """A WebAPI auth backend for handling OAuth2 tokens."""
 
-    def get_credentials(self, request):
+    def get_credentials(
+        self,
+        request: HttpRequest,
+    ) -> WebAPIGetCredentialsResult:
         """Return the credentials for authorization.
 
         This will parse the :mailheader:`Authorization` header and retrieve the
@@ -103,8 +132,8 @@ class WebAPIOAuth2TokenAuthBackend(WebAPIAuthBackend):
             import_module('oauth2_provider')
         except ImportError:
             raise ImproperlyConfigured(
-                'WebAPIOAuth2TokenAuthBackend requires django-oauth-toolkit'
-                '>=0.9,<0.9.999.'
+                'WebAPIOAuth2TokenAuthBackend requires a compatible version '
+                'of django-oauth-toolkit.'
             )
 
         http_auth = request.META['HTTP_AUTHORIZATION']
