@@ -2,6 +2,7 @@
 
 import logging
 import warnings
+from typing import Optional
 
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
@@ -17,6 +18,7 @@ from django.views.decorators.vary import vary_on_headers
 from djblets.auth.ratelimit import (RATE_LIMIT_API_ANONYMOUS,
                                     RATE_LIMIT_API_AUTHENTICATED,
                                     get_usage_count)
+from djblets.util.decorators import cached_property
 from djblets.util.http import (build_not_modified_from_response,
                                encode_etag,
                                etag_if_none_match,
@@ -143,9 +145,11 @@ class WebAPIResource(object):
             request._djblets_webapi_object_cache = {}
 
         auth_result = check_login(request)
+        headers = {}
 
         if isinstance(auth_result, tuple):
             auth_success, auth_message, auth_headers = auth_result
+            headers = auth_headers or {}
 
             if not auth_success:
                 err = LOGIN_FAILED
@@ -156,7 +160,7 @@ class WebAPIResource(object):
                 return WebAPIResponseError(
                     request,
                     err=err,
-                    headers=auth_headers or {},
+                    headers=headers,
                     api_format=api_format,
                     mimetype=self._build_error_mimetype(request))
 
@@ -173,13 +177,13 @@ class WebAPIResource(object):
 
         if (usage is not None and
             usage['count'] > usage['limit']):
+            headers['Retry-After'] = usage['time_left']
+            headers['X-RateLimit-Limit'] = usage['limit']
+
             return WebAPIResponseError(
                 request,
                 err=RATE_LIMIT_EXCEEDED,
-                headers={
-                    'Retry-After': usage['time_left'],
-                    'X-RateLimit-Limit': usage['limit'],
-                },
+                headers=headers,
                 api_format=api_format,
                 mimetype=self._build_error_mimetype(request))
 
@@ -237,15 +241,13 @@ class WebAPIResource(object):
                     api_format=api_format,
                     mimetype=self._build_error_mimetype(request))
             elif isinstance(result, tuple):
-                headers = {}
-
                 if method == 'GET':
                     request_params = request.GET
                 else:
                     request_params = request.POST
 
                 if len(result) == 3:
-                    headers = result[2]
+                    headers.update(result[2])
 
                 if 'Location' in headers:
                     extra_querystr = '&'.join([
@@ -264,7 +266,6 @@ class WebAPIResource(object):
                     response = WebAPIResponseError(
                         request,
                         err=result[0],
-                        headers=headers,
                         extra_params=result[1],
                         api_format=api_format,
                         mimetype=self._build_error_mimetype(request))
@@ -276,7 +277,6 @@ class WebAPIResource(object):
                         request,
                         status=result[0],
                         obj=result[1],
-                        headers=headers,
                         api_format=api_format,
                         encoder_kwargs=dict({
                             'calling_resource': self,
@@ -307,6 +307,11 @@ class WebAPIResource(object):
         else:
             response = HttpResponseNotAllowed(self.allowed_methods)
 
+        # Make sure any headers we've collected along the way are in the
+        # response.
+        for header_name, header_value in headers.items():
+            response.setdefault(header_name, header_value)
+
         return response
 
     @property
@@ -363,6 +368,55 @@ class WebAPIResource(object):
         """
         return self.name_plural
 
+    @cached_property
+    def uri_template_name(self) -> Optional[str]:
+        """Returns the name of the resource for use in URI templates.
+
+        This will be used as the key for this resource in
+        :py:class`djblets.webapi.resource.root.RootResource`'s list of URI
+        templates. This can be overridden when the URI template name for
+        this resource needs to differ from the name used for the resource.
+
+        This must be unique to the resource. If set to ``None`` this
+        resource will be excluded from the URI templates list.
+
+        Version Added:
+            3.1.0
+
+        Type:
+            str or None
+        """
+        return self.name
+
+    @cached_property
+    def uri_template_name_plural(self) -> Optional[str]:
+        """Returns the plural name of the resource for use in URI templates.
+
+        This will be used as the key for the list version of this resource in
+        :py:class`djblets.webapi.resource.root.RootResource`'s list of URI
+        templates. This can be overridden when the URI template name for
+        this resource needs to differ from the name used for the resource.
+
+        This must be unique to the resource. If set to ``None`` the list
+        version of this resource will be excluded from the URI templates list.
+
+        Version Added:
+            3.1.0
+
+        Type:
+            str or None
+        """
+        uri_template_name = self.uri_template_name
+
+        if uri_template_name is None:
+            return None
+        elif uri_template_name == self.name:
+            return self.name_plural
+        elif self.singleton:
+            return self.uri_template_name
+        else:
+            return uri_template_name + 's'
+
     def call_method_view(self, request, method, view, *args, **kwargs):
         """Calls the given method view.
 
